@@ -29,11 +29,13 @@ class TestInpadoc():
         result = Inpadoc.objects.get(publication="WO2009085664A2").biblio
         assert result.abstract is not None 
 
-
     def test_can_index_inpadoc_result(self):
         result = Inpadoc.objects.filter(applicant='Tesla')
         assert result[0] != result[1]
 
+    def test_can_handle_single_item_ipc_classes(self):
+        result = Inpadoc.objects.get(publication="WO2020081771").biblio
+        assert result.ipc_classes is not None
 
 class TestInpadocBiblio():
     def test_inpadoc_biblio_manager(self):
